Struct FnvHasher
struct FnvHasher(_)
An implementation of the Fowler–Noll–Vo hash function.
See the crate documentation for more details.
Implementations
impl FnvHasher
fn with_key(key: u64) -> FnvHasherCreate an FNV hasher starting with a state corresponding to the hash
key.
impl Default for FnvHasher
fn default() -> FnvHasher
impl Freeze for FnvHasher
impl Hasher for FnvHasher
fn finish(self: &Self) -> u64fn write(self: &mut Self, bytes: &[u8])
impl RefUnwindSafe for FnvHasher
impl Send for FnvHasher
impl Sync for FnvHasher
impl Unpin for FnvHasher
impl UnsafeUnpin for FnvHasher
impl UnwindSafe for FnvHasher
impl<T> Any for FnvHasher
fn type_id(self: &Self) -> TypeId
impl<T> Borrow for FnvHasher
fn borrow(self: &Self) -> &T
impl<T> BorrowMut for FnvHasher
fn borrow_mut(self: &mut Self) -> &mut T
impl<T> From for FnvHasher
fn from(t: T) -> TReturns the argument unchanged.
impl<T, U> Into for FnvHasher
fn into(self: Self) -> UCalls
U::from(self).That is, this conversion is whatever the implementation of
[From]<T> for Uchooses to do.
impl<T, U> TryFrom for FnvHasher
fn try_from(value: U) -> Result<T, <T as TryFrom<U>>::Error>
impl<T, U> TryInto for FnvHasher
fn try_into(self: Self) -> Result<U, <U as TryFrom<T>>::Error>